//-----------------------------------------------
// Add/Delete Analog configuration methods
//-----------------------------------------------
Ext.namespace("Paraxip.config.callControl");

var addAnalogConfHandler = function(){
  addAnalogConfWindow.show();
};

function addAnalogConfig(){
  var form = addAnalogConfigForm.getForm();
  var el  = form.getEl();

  el.dom.action = "call/addAnalogConfig";
  el.dom.method = 'POST';
  var analogConfig = Ext.util.JSON.encode(form.getValues());
  form.submit({
    params: {'analogConfig':analogConfig},
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      addAnalogConfWindow.hide();
      gridAnalogConfiguration.store.reload();
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

var deleteAnalogConfHandler = function(){
  var selectedRecords = gridAnalogConfiguration.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    if ( Paraxip.gridHasAnalogBoard(gridBoards) &&
          gridAnalogConfiguration.store.getCount() - selectedRecords.length < 1 ){
      Ext.Msg.alert("Can not delete last configuration!",
        "At least one configuration is necessary for the system to work properly. " +
        "Please edit current configuration or create a new one before deleting " +
        "this one");
    } else {
      var analogConfigs = new Array();
      for (var i = 0; i < selectedRecords.length; i++) {
        analogConfigs.push(selectedRecords[i].data);
      }
      analogConfigs = Ext.util.JSON.encode(analogConfigs);
      Ext.Ajax.request({
        url: 'call/deleteAnalogConfig',
        method: 'POST',
        disableCaching: false,
        params: {"analogConfigs":analogConfigs},
        success: function ()
        {
          Paraxip.isConfigOutOfSynch(true);
          for (var index = 0; index < selectedRecords.length; index++) {
            gridAnalogConfiguration.store.remove(selectedRecords[index]);
          }
          reloadTree(true);
        },
        failure: Paraxip.failureMessage
      });
    }
  }
};

var analogConfigChoice = new Ext.form.ComboBox({
  id              : 'analogConfigChoice',
  fieldLabel      : "Analog Config Type",
  store           : ['FXO'],// TODO add FXS
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  value           : 'FXO',
  selectOnFocus   : true,
  width           : 100
});

var addAnalogConfigForm = new Ext.FormPanel({
  id          : "addAnalogConfigForm",
  region      : 'center',
  labelWidth  : 175,
  labelPad    : 10,
  bodyStyle   : 'padding:10px;',
  frame       : false,
  header      : false,
  footer      : false,
  buttonAlign : "right",
  buttons     : [{
    id: "Paraxip.config.callControl.addConfigButton",
    text: "Add",
    listeners: {'click':addAnalogConfig}
  },{
    id: "Paraxip.config.callControl.cancelAddConfigButton",
    text: "Cancel",
    listeners: {'click':function(){addAnalogConfWindow.hide();}}
  }]
});

addAnalogConfigForm.add(analogConfigChoice);

var addAnalogConfWindow = new Ext.Window({
  id          : "addAnalogWindow",
  layout      : 'border',
  width       : 505,
  height      : 150,
  closeAction : 'hide',
  plain       : true
});

addAnalogConfWindow.add(addAnalogConfigForm);

var gridAnalogConfiguration = new Ext.grid.GridPanel({
  title       : 'Analog Configuration Grid',
  id          : 'gridAnalogConfiguration',
  autoScroll  : true,
  layout      : 'absolute',
  store       : new Ext.data.JsonStore({
    id: 'storeAnalogConfiguration',
    url: 'call/getGridAnalogConfigurationData',
    root: 'data',
    fields: [
      {name: 'id'},
      {name: 'displayName'},
      {name: 'nodeId'} //not displayed
    ]
  }),
  columns     : [
    {header: "ID", width: 35, sortable: true, dataIndex: 'id', css:'padding:5px;'},
    {header: "Name", width: 200, sortable: true, dataIndex: 'displayName', css:'padding:5px;'}
  ],
  viewConfig:{forceFit:true}
});

gridAnalogConfiguration.addButton("Add Analog Config",addAnalogConfHandler,
                                  gridAnalogConfiguration);
gridAnalogConfiguration.addButton("Remove Analog Config(s)",deleteAnalogConfHandler,
                                  gridAnalogConfiguration);

gridAnalogConfiguration.on('rowdblclick', function(grid, rowIndex){
  var record = grid.store.getAt(rowIndex);
  goToNode(record.get('nodeId'));
});

function isNumberofRingsVisible(){
  var notifyOutCond = notifyOutbound_condition_select;
  var numberOfRings = numOfRings_text;
  if( notifyOutCond.getValue() == "AFTER-N-RING") {
    numberOfRings.enable();
  } else {
    numberOfRings.disable();
    numberOfRings.clearInvalid();
  }
};

function isOnRemoteRingStoppedSelected(){
  var connectOutCond = connectOutBoundSide_condition_select;
  var disconnectTimeout = disconnectTimeoutMs_text;
  var connectOnNoRingTimeout = connectOnNoRemoteRingTimeoutMs_text;
  if( connectOutCond.getValue() == "ON-REMOTE-RING-STOPPED") {
    disconnectTimeout.enable();
    connectOnNoRingTimeout.enable();
  } else {
    disconnectTimeout.disable();
    disconnectTimeout.clearInvalid();
    connectOnNoRingTimeout.disable();
    connectOnNoRingTimeout.clearInvalid();
  }
};

function isRingCadenceDelayVisible(){
  var ringCadenceOn = ringCadenceDetector_active_select;
  var ringCadenceDelay = ringCadenceDetector_OffDelayMs_text;

  if( ringCadenceOn.getValue() == "YES" ) {
    ringCadenceDelay.enable();
  } else {
    ringCadenceDelay.disable();
  }
}

//------------------------------------------------
// Analog FXO config form
// -----------------------------------------------
function saveFxoConfig(e){
  var owner = e.ownerCt;
  var form = owner.getForm();
  var el = form.getEl();

  el.dom.action = 'call/saveFxoConfig';
  el.dom.method = 'POST';

  var fxoConfig = owner.getItemsValueAsJson();

  form.submit({
    params:{
      'frmAnalogFxo': fxoConfig
    },
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });
};

var frmAnalogFxo = new Ext.FormPanel({
  title         : "Analog FXO config",
  frame         : true,
  header        : false,
  id            : "frmAnalogFxo",
  autoScroll    : true,
  layout        : 'accordion',
  layoutConfig  : {
    activeItem  : 0
  },
  defaults      : {
    layout: 'form',
    style: 'text-align:left;',
    labelWidth: 150,
    bodyStyle: 'padding:5px;',
    width: 500,
    autoHeight: true,
    allowBlank: false,
    fill: true
  },
  buttonAlign   : "right",
  buttons       : [{
    id: "Paraxip.config.callControl.disconnectDetectorButton",
    text: 'Disconnection Detector(s)',
    listeners: {
      'click':function(){
        fxoConfigID = idFxo_text.getValue();
        analogFxoDetectorGrid.getStore().load({
          url: 'call/getFxoDetectors',
          params: {'id':fxoConfigID}
        });
        assignAnalogFxoDetectorWindow.show();
      }
    }
  },{
    id: "Paraxip.config.callControl.assignedInterfaceButton",
    text: 'Assigned Interface(s)',
    listeners: {
      'click':function(){
        fxoConfigID = idFxo_text.getValue();
        analogFxoInterfaceGrid.getStore().load({
          url: 'call/getFxoInterfaces',
          params: {'id':fxoConfigID}
        });
        storeAnalogFxoBoards.load({
          url: 'call/getAnalogBoards',
          params: {'id':fxoConfigID}
        });
        storeAnalogFxoChannelGroup.load({
          url: 'call/getChannelGroups',
          params: {'id':fxoConfigID}
        });
        assignAnalogFxoInterfaceWindow.show();
      }
    }
  },{
    id: "Paraxip.config.callControl.saveFxoConfigButton",
    text: 'Save',
    listeners: {'click':saveFxoConfig}
  },{
    id: "Paraxip.config.callControl.cancelSaveConfigButton",
    text: 'Cancel',
    listeners: {'click':callControlCancel}
  }]
});

var fxoConfigPanel = new Ext.Panel({
  id    : 'fxoConfigPanel',
  name  : 'fxoConfig',
  title : 'Configuration Info',
  items : [{
    xtype: 'textfield',
    name: 'nodeId',
    hidden: true,
    hideLabel: true
  }]
});

var inboundCallHandlingPanel = new Ext.Panel({
  id    : 'inboundCallHandlingPanel',
  name  : 'inboundCall',
  title : 'Inbound Call Handling Info'
});

var outboundCallDialingPanel = new Ext.Panel({
  id    : 'outboundCallDialingPanel',
  name  : 'outboundCallDialing',
  title : 'Outbound Dialing Info'
});

var outboundConnectPanel = new Ext.Panel({
  id    : 'outboundConnectPanel',  
  name  : 'outboundCallConnect',
  title : 'Outbound Connect Info'
});

var disconnectSupervisionPanel = new Ext.Panel({
  id    : 'disconnectSupervisionPanel',
  name  : 'disconnectSupervision',
  title : 'Disconnect Supervision Info'
});

var idFxo_text = createIdText({
  id        : 'idFxo_text',
  helpText  : 'analogFxoConfiganalogFxoConfigID'
});

var nameFxo_text = createNameText({
  id        : 'nameFxo_text',
  helpText  : 'analogFxoConfiganalogFxoConfigdisplayName'
});

var minimumOnHookDurationMs = createMinimumOnHookDurationMs({
  id        : 'minimumOnHookDurationMs',
  helpText  : 'analogFxoConfiganalogFxoConfigminimumOnHookDurationMs'
});

var numOfRings_text = new Ext.form.NumberField({
  id            : 'numOfRings_text',
  fieldLabel    : "Number Of Rings",
  name          : "numberOfRings",
  helpText      : "notifyOutboundSideParametersnotifyOutboundSidenumberOfRings",
  allowNegative : false,
  allowBlank    : false,
  disabled      : true,
  width         : 217
});

var notifyOutbound_condition_select = new Ext.form.ComboBox({
  id              : 'notifyOutbound_condition_select',
  name            : 'notifyOutbound_condition',
  fieldLabel      : "Notify Outbound Side Condition",
  store           : ['ON-FIRST-RING','ON-CALLER-ID','AFTER-N-RING'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 200,
  minListWidth    : 200,
  listeners       : {
    'select':isNumberofRingsVisible
  }
});

var notifyOutbound_delay_text = new Ext.form.NumberField({
  id              : 'notifyOutbound_delay_text',
  fieldLabel      : "Notify Outbound Side Delay (ms)",
  name            : "notifyOutbound_delay",
  helpText        : "notifyOutboundSideParametersnotifyOutboundSidedelayInMs",
  allowNegative   : false,
  allowBlank      : false,
  width           : 217
});

var notifyOutboundConnect_condition_select = new Ext.form.ComboBox({
  id              : 'notifyOutboundConnect_condition_select',
  name            : 'connect_condition',
  fieldLabel      : "Connect Inbound Side Condition",
  store           : ['ON-OUTBOUNDSIDE-NOTIFIED','ON-OUTBOUNDSIDE-CONNECTED'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 200,
  minListWidth    : 200
});

var callerID_type_select = new Ext.form.ComboBox({
  id              : 'callerID_type_selection',
  name            : 'callerID_type',
  fieldLabel      : "CallerID Type",
  store           : ['Bellcore-FSK-SDMF-MDMF'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 200,
  minListWidth    : 200
});

var dial_active_select = new Ext.form.ComboBox({
  id              : 'dial_active_selection',
  name            : 'dial_active',
  fieldLabel      : "Active",
  helpText        : "dialParametersdialactive",
  store           : ['YES','NO'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 235,
  minListWidth    : 235
});

var dial_waitForDialTone_select = new Ext.form.ComboBox({
  id              : 'dial_waitForDialTone_selection',
  name            : 'dial_waitForDialTone',
  fieldLabel      : "Wait For Dial Tone",
  helpText        : "dialParametersdialwaitForDialTone",
  store           : ['YES','NO'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 235,
  minListWidth    : 235
});

var preDialDelayInMs_text = new Ext.form.NumberField({
  id            : 'preDialDelayInMs_text',
  fieldLabel    : "Pre Dial Delay (ms)",
  name          : "preDialDelayInMs",
  helpText      : "dialParametersdialpreDialDelayInMs",
  allowNegative : false,
  allowBlank    : false,
  width         : 252
});

var interDigitDelayInMs_text = new Ext.form.NumberField({
  id            : 'interDigitDelayInMs_text',
  fieldLabel    : "InterDigit Delay (ms)",
  name          : "interDigitDelayInMs",
  helpText      : "dialParametersdialinterDigitDelayInMs",
  allowNegative : false,
  allowBlank    : false,
  width         : 252
});

var dTMFDigitDurationInMs_text = new Ext.form.NumberField({
  id            : 'dTMFDigitDurationInMs_text',
  fieldLabel    : "DTMF Digit Duration (ms)",
  name          : "dTMFDigitDurationInMs",
  helpText      : "dialParametersdialDTMFDigitDurationInMs",
  allowNegative : false,
  allowBlank    : false,
  width         : 252
});


var disconnectTimeoutMs_text = new Ext.form.NumberField({
  id            : 'disconnectTimeoutMs_text',
  fieldLabel    : "Disconnect Timeout(ms)",
  name          : "disconnectTimeoutMs",
  //helpText      : "notifyOutboundSideParametersnotifyOutboundSidenumberOfRings",
  allowNegative : false,
  allowBlank    : false,
  disabled      : true,
  width         : 217
});

var connectOnNoRemoteRingTimeoutMs_text = new Ext.form.NumberField({
  id            : 'connectOnNoRemoteRingTimeoutMs_text',
  fieldLabel    : "Connect On No Remote Ring Timeout(ms)",
  name          : "connectOnNoRemoteRingTimeoutMs",
  //helpText      : "notifyOutboundSideParametersnotifyOutboundSidenumberOfRings",
  allowNegative : false,
  allowBlank    : false,
  disabled      : true,
  width         : 217
});

var connectOutBoundSide_condition_select = new Ext.form.ComboBox({
  id              : 'connectOutBoundSide_condition_selection',
  name            : 'connectOutBoundSide_condition',
  fieldLabel      : "Connect Outbound Side Condition",
  helpText        : "connectSupervisionParametersconnectSupervisionconnectOutboundSidecondition",
  store           : ['AFTER-DIALING-DESTINATION-NUMBER','ON-REMOTE-RING-STOPPED',/*'ON-VOICE',*/'ON-BATTERY-POLARITY-INVERSION'], //ON-VOICE not supported for now
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 235,
  minListWidth    : 235,
  listeners       : {
    'select':isOnRemoteRingStoppedSelected
  }
});

var connectParamOutbound_condition_select = new Ext.form.ComboBox({
  id              : 'connectParamOutbound_condition_selection',
  name            : 'connectParamOutbound_condition',
  fieldLabel      : "Connect Inbound Side Condition",
  helpText        : "connectParametersOutboundconnectcondition",
  store           : ['ON-OUTBOUNDSIDE-CONNECTED','ON-OUTBOUNDSIDE-NOTIFIED',
                     'ON-INBOUNDSIDE-NOTIFICATION'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 215,
  minListWidth    : 215
});

var connectParamOutbound_delayInMs_text = new Ext.form.NumberField({
  id            : 'connectParamOutbound_delayInMs_text',
  fieldLabel    : "Connect Inbound Side Delay (ms)",
  name          : "connectParamOutbound_delayInMs",
  helpText      : "connectParametersOutboundconnectdelayInMs",
  allowNegative : false,
  allowBlank    : false,
  width         : 232
});

var ringCadenceDetector_active_select = new Ext.form.ComboBox({
  id              : 'ringCadenceDetector_active_selection',
  name            : 'ringCadenceDetector_active',
  fieldLabel      : "Ring Cadence Detector Active",
  helpText        : "disconnectSupervisionParametersdisconnectSupervisiondisconnectDetectorsringCadenceDetectoractive",
  store           : ['YES','NO'],
  forceSelection  : true,
  triggerAction   : 'all',
  mode            : 'local',
  typeAhead       : true,
  selectOnFocus   : true,
  width           : 145,
  minListWidth    : 145,
  listeners       : {
    'select':isRingCadenceDelayVisible
  }
});

var ringCadenceDetector_OffDelayMs_text = new Ext.form.NumberField({
  id            : 'ringCadenceDetector_OffDelayMs_text',
  fieldLabel    : "Ring Cadence Off Delay (ms)",
  name          : "ringCadenceDetector_OffDelayMs",
  helpText      : "disconnectSupervisionParametersdisconnectSupervisiondisconnectDetectorsringCadenceDetectorringCadenceOffDelayMs",
  allowNegative : false,
  allowBlank    : false,
  width         : 162
});

fxoConfigPanel.add(idFxo_text);
fxoConfigPanel.add(nameFxo_text);
fxoConfigPanel.add(minimumOnHookDurationMs);
frmAnalogFxo.add(fxoConfigPanel);

inboundCallHandlingPanel.add(notifyOutbound_condition_select);
inboundCallHandlingPanel.add(numOfRings_text);
inboundCallHandlingPanel.add(notifyOutbound_delay_text);
inboundCallHandlingPanel.add(notifyOutboundConnect_condition_select);
inboundCallHandlingPanel.add(callerID_type_select);
frmAnalogFxo.add(inboundCallHandlingPanel);

outboundCallDialingPanel.add(dial_active_select);
outboundCallDialingPanel.add(dial_waitForDialTone_select);
outboundCallDialingPanel.add(preDialDelayInMs_text);
outboundCallDialingPanel.add(interDigitDelayInMs_text);
outboundCallDialingPanel.add(dTMFDigitDurationInMs_text);
frmAnalogFxo.add(outboundCallDialingPanel);

outboundConnectPanel.add(connectOutBoundSide_condition_select);
outboundConnectPanel.add(disconnectTimeoutMs_text);
outboundConnectPanel.add(connectOnNoRemoteRingTimeoutMs_text);
outboundConnectPanel.add(connectParamOutbound_condition_select);
outboundConnectPanel.add(connectParamOutbound_delayInMs_text);
frmAnalogFxo.add(outboundConnectPanel);

disconnectSupervisionPanel.add(ringCadenceDetector_active_select);
disconnectSupervisionPanel.add(ringCadenceDetector_OffDelayMs_text);
frmAnalogFxo.add(disconnectSupervisionPanel);

function applyToFxoConfig(e){
  var grid = e.ownerCt;
  var url;
  var params;
  var gridData;
  var records;
  var i;

  if( grid.getItemId() == "analogFxoInterfaceGrid") {
    url = "call/applyInterfacesToFxoConfig";
    records = grid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
    params = {'gridData':gridData,'fxoConfigID':Ext.util.JSON.encode(fxoConfigID)};
  }//TODO - Add FXS

  Ext.Ajax.request({
    url: url,
    method: 'POST',
    disableCaching: false,
    params: params,
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      grid.ownerCt.hide();
      //reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });

};

function addAnalogFxoInterface(e){
  var form = e.ownerCt;

  if( storeAnalogFxoBoards.data.length < 1 ) {
    Ext.Msg.alert("No Analog boards in config","There is no analog boards in your configuration."+
                  " Please add a board in the board section if you want to assign a board to this config.");
    return;
  }

  var firstBoardId = storeAnalogFxoBoards.getAt(0).get('id');
  storeAnalogFxoInterfaces.load({
    url: 'call/getAnalogInterfaces',
    disableCaching: false,
    params: {'id':firstBoardId}
  });
  if( form.id == 'analogFxoInterfaceGrid' ) {
    var newRecord = new DataRecord({
      'boardId':storeAnalogFxoBoards.getAt(0).get('id'),
      'interfaceId':1,
      'channelGroupID':storeAnalogFxoChannelGroup.getAt(0).get('id')
    });
    analogFxoInterfaceGrid.getStore().add(newRecord);
    analogFxoInterfaceGrid.expand();
  }
};

function deleteFxoInterface(e){
  var grid = e.ownerCt;

  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }
};

var fxoConfigID = '';

var storeAnalogFxoBoards = new Ext.data.JsonStore({
  id: 'storeAnalogFxoBoards',
  url: 'call/getAnalogBoards',
  root: 'data',
  fields: ['id','displayName','nodeId']
});

var storeAnalogFxoInterfaces = new Ext.data.JsonStore({
  id: 'storeAnalogFxoInterfaces',
  url: 'call/getAnalogInterfaces',
  root: 'data',
  fields: ['id','displayName']
});

var storeAnalogFxoChannelGroup = new Ext.data.JsonStore({
  id: 'storeAnalogFxoChannelGroup',
  url: 'call/getChannelGroups',
  root: 'data',
  fields: ['id']
});

var assignAnalogFxoInterfaceWindow = new Ext.Window({
  title       : 'Assign Analog Interface to Fxo Config',
  layout      : 'fit',
  layoutConfig: {
      autoWidth : false
  },
  width       : 600,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignAnalogFxoInterfaceWindow"
});

var analogFxoInterfaceGrid = new Ext.grid.EditorGridPanel({
  title       : 'Analog Interfaces assigned to config',
  id          : 'analogFxoInterfaceGrid',
  autoScroll  : true,
  width       : 500,
  height      : 400,    
  clicksToEdit: 2,
  enableColumnMove : false,
  selModel    : new Ext.grid.RowSelectionModel(),
  store       : new Ext.data.JsonStore({
    id: 'storeAnalogFxoInterfaceGrid',
    url: 'call/getFxoInterfaces',
    root: 'data',
    fields: [
      {name: 'boardId'},
      {name: 'interfaceId'},
      {name: 'channelGroupID'},
      {name: 'nodeId'} //not displayed
    ]
  }),
  columns     :[
    {
      header: "Board ID",
      width: 95,
      sortable: true,
      dataIndex: 'boardId',
      editor: new Ext.form.ComboBox({
        forceSelection  : true,
        triggerAction   : 'all',
        mode            : 'local',
        selectOnFocus   : true,
        valueField      : 'id',
        displayField    : 'id',
        store           : storeAnalogFxoBoards,
        listClass       : 'x-combo-list-small'
      })
    },
    {
      header: "Interface ID",
      width: 95,
      sortable: true,
      dataIndex: 'interfaceId',
      editor: new Ext.form.ComboBox({
        forceSelection  : true,
        triggerAction   : 'all',
        mode            : 'local',
        selectOnFocus   : true,
        valueField      : 'id',
        displayField    : 'id',
        store           : storeAnalogFxoInterfaces,
        listClass       : 'x-combo-list-small'
      })
    },
    {
      header: "Channel Group ID",
      width: 105,
      sortable: true,
      dataIndex: 'channelGroupID',
      editor: new Ext.form.ComboBox({
        forceSelection  : true,
        triggerAction   : 'all',
        mode            : 'local',
        selectOnFocus   : true,
        valueField      : 'id',
        displayField    : 'id',
        store           : storeAnalogFxoChannelGroup,
        listClass       : 'x-combo-list-small'
      })
    }
  ],
  listeners       : {
    'afteredit':function(e){
      if( e.field == "boardId" ) {
        var colModel = e.grid.getColumnModel();
        var newColumn = e.column+1;
        var cellEditor = colModel.getCellEditor(newColumn,e.row);
        cellEditor.field.store.load({
          url: 'call/getAnalogInterfaces',
          disableCaching: false,
          params: {'id':e.value}
        });
      }
    }
  },
  viewConfig:{forceFit:true}
});

analogFxoInterfaceGrid.store.on('load',function(store){
  store.each(function(record,index){
                var colModel = analogFxoInterfaceGrid.getColumnModel();
    colModel.getCellEditor(1,index).field.store.load({
      url: 'call/getAnalogInterfaces',
      disableCaching: false,
      params: {'id':record.data['boardId']}
    });
  });
});

analogFxoInterfaceGrid.addButton("Add Analog Interface",addAnalogFxoInterface,analogFxoInterfaceGrid); 
analogFxoInterfaceGrid.addButton("Delete",deleteFxoInterface,analogFxoInterfaceGrid);
analogFxoInterfaceGrid.addButton("Save",applyToFxoConfig,analogFxoInterfaceGrid);
analogFxoInterfaceGrid.addButton("Cancel",function(){assignAnalogFxoInterfaceWindow.hide();});

assignAnalogFxoInterfaceWindow.add(analogFxoInterfaceGrid);

//------------------
function applyFxoDetector(e){
  var grid = e.ownerCt;
  var url;
  var params;
  var gridData;
  var records;
  var i;

  if( grid.getItemId() == "analogFxoDetectorGrid" ) {
    url = "call/applyDetectorsToFxoConfig";
    records = grid.getStore().getRange();
    gridData = new Array();
    for (i = 0; i < records.length; i++) {
      gridData.push(records[i].data);
    }
    gridData = Ext.util.JSON.encode(gridData);
    params = {'gridData':gridData,'fxoConfigID':Ext.util.JSON.encode(fxoConfigID)};
  }//TODO - Add FXS

  Ext.Ajax.request({
    url: url,
    method: 'POST',
    disableCaching: false,
    params: params,
    success: function(){
      Paraxip.isConfigOutOfSynch(true);
      grid.ownerCt.hide();
      reloadTree(true);
    },
    failure: Paraxip.failureMessage
  });

};

function addAnalogFxoDetector(e){
  var form = e.ownerCt;
  //var values = form.getForm().getValues(false);

  if( form.id == 'analogFxoDetectorGrid' ) {
    var newRecord = new DataRecord({
      'name':'new_detector',
      'sequence':'Please enter valid sequence. See Help button for more informations.'
    });
    analogFxoDetectorGrid.getStore().add(newRecord);
    //analogFxoDetectorGrid.expand();
  }//TODO - Add FXS
};

function deleteFxoDetector(e){
  var grid = e.ownerCt;

  var selectedRecords = grid.getSelectionModel().getSelections();

  if (selectedRecords !== []) {
    for( i = 0; i < selectedRecords.length; i++ ) {
      grid.getStore().remove(selectedRecords[i]);
    }
  }
};

var storeAnalogFxoDetectors = new Ext.data.JsonStore({
  id: 'storeAnalogFxoDetectors',
  url: 'call/getAnalogDetectors',
  root: 'data',
  fields: ['name','sequence']
});

var assignAnalogFxoDetectorWindow = new Ext.Window({
  title       : 'Assign Analog Detector to Fxo Config',
  layout      : 'fit',
  layoutConfig: {
      autoWidth : false
  },
  width       : 600,
  height      : 500,
  closeAction : 'hide',
  resizable   : false,
  plain       : true,
  id          : "assignAnalogFxoDetectorWindow"
});

var detectorsHelpWindow = new Ext.Window({
  id          : "Paraxip.config.callControl.detectorsHelpWindow",
  title       : "Detectors help",
  layout      : "border",
  width       : 505,
  height      : 150,
  closeAction : 'hide',
  plain       : true
  
});

var detectorsHelpTextArea= new Ext.form.TextArea({
  id          : 'Paraxip.config.callControl.detectorsHelpTextArea',
  hideLabel   : true,
  style       : "height: 113px; width: 482px;",
  region      : 'center',
  readOnly    : true,
  value       : 'Specify a disconnect sequence: sequence := term (\',\' term)* ; term := event \'/\' duration ; event := \"silence\" | \"dial\" | \"sit\" | \"reorder\" | \"busy\" | \"disconnect\" | \"batteryDisconnect\" | \"batteryPolarityInversion\" ; duration := durationInSecond | \"continuous\"; ; durationInSecond := real_number ;'
});

detectorsHelpWindow.add(detectorsHelpTextArea);


var analogFxoDetectorGrid = new Ext.grid.EditorGridPanel({
  title       : 'Analog Detectors assigned to config',
  id          : 'analogFxoDetectorGrid',
  autoScroll  : true,
  width       : 500,
  height      : 400,
  clicksToEdit: 2,
  selModel    : new Ext.grid.RowSelectionModel(),
  store       : new Ext.data.JsonStore({
    id: 'storeAnalogFxoDetectorGrid',
    url: 'call/getFxoDetectors',
    root: 'data',
    fields: [
      {name: 'name'},
      {name: 'sequence'}
    ]
  }),
  columns     :[
    {
      header: "Name",
      width: 95,
      sortable: true,
      dataIndex: 'name',
      editor: new Ext.form.TextField({
        fieldLabel  : "Name",
        name        : "detector_name"
      })
    },
    {
      header: "Sequence",
      width: 95,
      sortable: true,
      dataIndex: 'sequence',
      selectOnFocus: true,
      editor: new Ext.form.TextField({
        fieldLabel  : "Sequence",
        name        : "detector_sequence"
      })
    }
  ],
  viewConfig:{forceFit:true}
});

analogFxoDetectorGrid.addButton("Help",function(){detectorsHelpWindow.show()});
analogFxoDetectorGrid.addButton("Add",addAnalogFxoDetector,analogFxoDetectorGrid);
analogFxoDetectorGrid.addButton("Delete",deleteFxoDetector,analogFxoDetectorGrid);
analogFxoDetectorGrid.addButton("Save",applyFxoDetector,analogFxoDetectorGrid);
analogFxoDetectorGrid.addButton("Cancel",function(){assignAnalogFxoDetectorWindow.hide();});

assignAnalogFxoDetectorWindow.add(analogFxoDetectorGrid);


